@@ -20,7 +20,7 @@ my_params <- function(x) {
       "leg_pos position of the legend, one of 'topleft', 'top',",
       "'topright', 'right', 'bottomright', 'bottom', ",
       "'bottomleft', 'left' or a vector of two coordinates ",
-      "in map units (c(x, y)). If leg_pos is 'n' then the ",
+      "in map units (c(x, y)). If leg_pos = NA then the ",
       "legend is not plotted."
     ),
     leg_pos2 = paste0(
@@ -29,7 +29,7 @@ my_params <- function(x) {
       "coordinates in map units (c(x, y)). leg_pos argument can be ",
       "c('position', 'position'), c('position', x2, y2), ",
       "c(x1,y1, 'position') or c(x1, y1, x2, y2). ",
-      "If leg_pos is 'n' then the legend is not plotted."
+      "If leg_pos = NA then the legend is not plotted."
     ),
     leg_title = "leg_title legend title",
     leg_title_cex = "leg_title_cex size of the legend title",
