@@ -24,14 +24,14 @@ NULL
 globalVariables(".gmapsf", package = "mapsf", add = FALSE)
 .gmapsf$args <- list(
   name = "default",
-  bg = "white",
-  fg = "black",
-  mar = c(5.1, 4.1, 4.1, 2.1),
+  bg = "#f7f7f7",
+  fg = "#333333",
+  mar = c(.5, .5, 1.7, .5),
   tab = TRUE,
   pos = "left",
   inner = FALSE,
   line = 1.2,
   cex = 1,
-  font = 2
+  font = 1
 )
 .gmapsf$inset <- FALSE
